# -*- coding: utf-8 -*-
"""
/***************************************************************************
 MultiBuf
                                 A QGIS plugin
 Create multiple buffers
                              -------------------
        begin                : 2014-02-22
        copyright            : (C) 2014 by Adrien Caillot
        email                : adrien.caillot@univ-fcomte.fr
 ***************************************************************************/

/***************************************************************************
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of the GNU General Public License as published by  *
 *   the Free Software Foundation; either version 2 of the License, or     *
 *   (at your option) any later version.                                   *
 *                                                                         *
 ***************************************************************************/
"""
# Import the PyQt and QGIS libraries
from PyQt4.QtCore import *
from PyQt4.QtGui import *
from qgis.core import *
# Initialize Qt resources from file resources.py
import resources_rc
# Import the code for the dialog
from multibufdialog import MultiBufDialog
import os.path


class MultiBuf:

    def __init__(self, iface):
        # Save reference to the QGIS interface
        self.iface = iface
        # initialize plugin directory
        self.plugin_dir = os.path.dirname(__file__)
        # initialize locale
        locale = QSettings().value("locale/userLocale")[0:2]
        localePath = os.path.join(self.plugin_dir, 'i18n', 'multibuf_{}.qm'.format(locale))

        if os.path.exists(localePath):
            self.translator = QTranslator()
            self.translator.load(localePath)

            if qVersion() > '4.3.3':
                QCoreApplication.installTranslator(self.translator)

        # Create the dialog (after translation) and keep reference
        self.dlg = MultiBufDialog()

    def initGui(self):
        # Create action that will start plugin configuration
        self.action = QAction(
            QIcon(":/plugins/multibuf/icon.png"),
            u"Create multiple buffers", self.iface.mainWindow())
        # connect the action to the run method
        self.action.triggered.connect(self.run)

        # Add toolbar button and menu item
        self.iface.addToolBarIcon(self.action)
        self.iface.addPluginToMenu(u"&MultiBuffers", self.action)

    def unload(self):
        # Remove the plugin menu item and icon
        self.iface.removePluginMenu(u"&MultiBuffers", self.action)
        self.iface.removeToolBarIcon(self.action)

    # run method that performs all the real work
    def run(self):
        # show the dialog
        self.dlg.show()
        # Run the dialog event loop
        result = self.dlg.exec_()
        # See if OK was pressed
        if result == 1:
            # do something useful (delete the line containing pass and
            # substitute with your code)
            self.nbbuf = self.dlg.nbbuf.value()
            self.distance = self.dlg.distance.value()
            self.layer = self.iface.mapCanvas().currentLayer()
            self.selected = self.layer.selectedFeatures()
            self.crs = self.layer.crs()

            ladistance = self.distance

            for houba in range(0, self.nbbuf):

                # Create a memory layer for storing the results
                resultl = QgsVectorLayer("Polygon?crs=epsg:4326", "result" + str(ladistance), "memory")
	        resultl.setCrs(self.crs) 
                resultpr = resultl.dataProvider()

	        featuresScaled = []

                for coin in self.selected:
        	    coin.setGeometry(coin.geometry().buffer(self.distance,5))
                    featuresScaled.append(coin)
		    
                ladistance = ladistance + self.distance

                self.iface.mainWindow().statusBar().showMessage("Adding features to results layer")
                resultpr.addFeatures(featuresScaled)
                QgsMapLayerRegistry.instance().addMapLayer(resultl)

#            self.message = self.nbbufstr + " buffers requested with distance " + self.distancestr + " on the layer " + self.layer.name() + " for " + nbselect + " selected features"

            
#	    QMessageBox.information(self.iface.mainWindow(), QCoreApplication.translate('title', "Info"), QCoreApplication.translate('themessage', self.message))

